
//***************************************************
// Generalised Bitmap Module C++ adapter for GBM plugins
//
// Requires: GBM.DLL version 1.35 or higher (with multipage support)
//
// Copyright (C) 2006 Heiko Nitzsche
//
//   This software is provided 'as-is', without any express or implied
//   warranty.  In no event will the author be held liable for any damages
//   arising from the use of this software.
//
//   Permission is granted to anyone to use this software for any purpose,
//   including commercial applications, and to alter it and redistribute it
//   freely, subject to the following restrictions:
//
//   1. The origin of this software must not be misrepresented; you must not
//      claim that you wrote the original software. If you use this software
//      in a product, an acknowledgment in the product documentation would be
//      appreciated but is not required.
//   2. Altered source versions must be plainly marked as such, and must not be
//      misrepresented as being the original software.
//   3. This notice may not be removed or altered from any source distribution.
//
//***************************************************

#ifndef __CLASS_GBM_RENDERER__
    #define __CLASS_GBM_RENDERER__

#include "gbm.h"

#include "GbmException.hpp"
#include "GbmDocumentPage.hpp"

// ---------------------------------------------------------

class GbmRenderer
{
    private:

        class CacheDescription
        {
            private:
                const byte * constData;
                      byte * data;

            public:
                int       width;
                int       height;
                int       rowStride;
                double    scale_x, scale_y;

                CacheDescription()
                    : constData(NULL),
                      data(NULL),
                      width(0),
                      height(0),
                      rowStride(0),
                      scale_x(1.0),
                      scale_y(1.0)
                {
                }

                virtual ~CacheDescription()
                {
                    clear();
                }

                void setConstData(const byte * const_data)
                {
                    constData = const_data;
                    delete [] data;
                    data = NULL;
                }
                void setData(byte * data)
                {
                    constData = NULL;
                    delete [] (this->data);
                    this->data = data;
                }
                BOOLEAN isConstData() const
                {
                    return (constData != NULL);
                }
                const byte * getDataPtr() const
                {
                    return isConstData() ? constData : data;
                }

                void clear()
                {
                    delete [] data;
                    data      = NULL;
                    constData = NULL;
                    width     = 0;
                    height    = 0;
                    rowStride = 0;
                    scale_x   = 1.0;
                    scale_y   = 1.0;
                }
        };

        GbmDocumentPage  * renderPage;
        CacheDescription   cacheDescription;

        int unscaledWidth;
        int unscaledHeight;

    public:

        GbmRenderer();
        virtual ~GbmRenderer();

        void setRenderPage(GbmDocumentPage * page);
        GbmDocumentPage * getRenderPage() const;

        void renderToBuffer(long     src_x    , long   src_y,
                            long     src_width, long   src_height,
                            double   scale_x  , double scale_y,
                            byte   * buffer) throw ( GbmException );
};

#endif


